@@ -61,24 +61,25 @@ protected:
   friend class SBProcess;
   friend class SBStructuredData;
   friend class SBThread;
+  friend class SBTrace;
   friend class SBTarget;
   friend class SBValue;
   friend class SBWatchpoint;
   friend class SBBreakpoint;
   friend class SBBreakpointLocation;
 
-  lldb_private::Error *get();
+  lldb_private::Status *get();
 
-  lldb_private::Error *operator->();
+  lldb_private::Status *operator->();
 
-  const lldb_private::Error &operator*() const;
+  const lldb_private::Status &operator*() const;
 
-  lldb_private::Error &ref();
+  lldb_private::Status &ref();
 
-  void SetError(const lldb_private::Error &lldb_error);
+  void SetError(const lldb_private::Status &lldb_error);
 
 private:
-  std::unique_ptr<lldb_private::Error> m_opaque_ap;
+  std::unique_ptr<lldb_private::Status> m_opaque_ap;
 
   void CreateIfNeeded();
 };
