@@ -19,8 +19,8 @@
 #include "llvm/ADT/DenseMap.h"
 
 // Project includes
-#include "lldb/Core/ConstString.h"
 #include "lldb/Core/ValueObject.h"
+#include "lldb/Utility/ConstString.h"
 #include "lldb/lldb-public.h"
 
 namespace lldb_private {
