@@ -99,6 +99,13 @@ public:
                                                    Thread &thread,
                                                    int current_offset);
 
+  lldb::UnwindPlanSP GetDebugFrameUnwindPlan(Target &target,
+                                             int current_offset);
+
+  lldb::UnwindPlanSP GetDebugFrameAugmentedUnwindPlan(Target &target,
+                                                      Thread &thread,
+                                                      int current_offset);
+
   lldb::UnwindPlanSP GetCompactUnwindUnwindPlan(Target &target,
                                                 int current_offset);
 
@@ -126,10 +133,12 @@ private:
 
   lldb::UnwindPlanSP m_unwind_plan_assembly_sp;
   lldb::UnwindPlanSP m_unwind_plan_eh_frame_sp;
-  lldb::UnwindPlanSP m_unwind_plan_eh_frame_augmented_sp; // augmented by
-                                                          // assembly inspection
-                                                          // so it's valid
-                                                          // everywhere
+  lldb::UnwindPlanSP m_unwind_plan_debug_frame_sp;
+
+  // augmented by assembly inspection so it's valid everywhere
+  lldb::UnwindPlanSP m_unwind_plan_eh_frame_augmented_sp;
+  lldb::UnwindPlanSP m_unwind_plan_debug_frame_augmented_sp;
+
   std::vector<lldb::UnwindPlanSP> m_unwind_plan_compact_unwind;
   lldb::UnwindPlanSP m_unwind_plan_arm_unwind_sp;
   lldb::UnwindPlanSP m_unwind_plan_fast_sp;
@@ -139,7 +148,9 @@ private:
   // Fetching the UnwindPlans can be expensive - if we've already attempted
   // to get one & failed, don't try again.
   bool m_tried_unwind_plan_assembly : 1, m_tried_unwind_plan_eh_frame : 1,
+      m_tried_unwind_plan_debug_frame : 1,
       m_tried_unwind_plan_eh_frame_augmented : 1,
+      m_tried_unwind_plan_debug_frame_augmented : 1,
       m_tried_unwind_plan_compact_unwind : 1,
       m_tried_unwind_plan_arm_unwind : 1, m_tried_unwind_fast : 1,
       m_tried_unwind_arch_default : 1,
