@@ -5,7 +5,6 @@ Test denied process attach.
 from __future__ import print_function
 
 
-
 import os
 import time
 import lldb
@@ -15,6 +14,7 @@ from lldbsuite.test import lldbutil
 
 exe_name = 'AttachDenied'  # Must match Makefile
 
+
 class AttachDeniedTestCase(TestBase):
 
     mydir = TestBase.compute_mydir(__file__)
@@ -28,8 +28,11 @@ class AttachDeniedTestCase(TestBase):
 
         # Use a file as a synchronization point between test and inferior.
         pid_file_path = lldbutil.append_to_process_working_directory(
-                "pid_file_%d" % (int(time.time())))
-        self.addTearDownHook(lambda: self.run_platform_command("rm %s" % (pid_file_path)))
+            "pid_file_%d" % (int(time.time())))
+        self.addTearDownHook(
+            lambda: self.run_platform_command(
+                "rm %s" %
+                (pid_file_path)))
 
         # Spawn a new process
         popen = self.spawnSubprocess(exe, [pid_file_path])
@@ -38,5 +41,5 @@ class AttachDeniedTestCase(TestBase):
         pid = lldbutil.wait_for_file_on_target(self, pid_file_path)
 
         self.expect('process attach -p ' + pid,
-                    startstr = 'error: attach failed:',
-                    error = True)
+                    startstr='error: attach failed:',
+                    error=True)
