@@ -226,19 +226,19 @@ def MakeInlineTest(__file, __globals, decorators=None):
 
     target_platform = lldb.DBG.GetSelectedPlatform().GetTriple().split('-')[2]
     if test_categories.is_supported_on_platform(
-            "dsym", target_platform, configuration.compilers):
+            "dsym", target_platform, configuration.compiler):
         test.test_with_dsym = ApplyDecoratorsToFunction(
             test._InlineTest__test_with_dsym, decorators)
     if test_categories.is_supported_on_platform(
-            "dwarf", target_platform, configuration.compilers):
+            "dwarf", target_platform, configuration.compiler):
         test.test_with_dwarf = ApplyDecoratorsToFunction(
             test._InlineTest__test_with_dwarf, decorators)
     if test_categories.is_supported_on_platform(
-            "dwo", target_platform, configuration.compilers):
+            "dwo", target_platform, configuration.compiler):
         test.test_with_dwo = ApplyDecoratorsToFunction(
             test._InlineTest__test_with_dwo, decorators)
     if test_categories.is_supported_on_platform(
-            "gmodules", target_platform, configuration.compilers):
+            "gmodules", target_platform, configuration.compiler):
         test.test_with_gmodules = ApplyDecoratorsToFunction(
             test._InlineTest__test_with_gmodules, decorators)
 
