@@ -883,12 +883,13 @@ class GdbRemoteTestCaseBase(TestBase):
     def add_set_breakpoint_packets(
             self,
             address,
+            z_packet_type=0,
             do_continue=True,
             breakpoint_kind=1):
         self.test_sequence.add_log_lines(
             [  # Set the breakpoint.
-                "read packet: $Z0,{0:x},{1}#00".format(
-                    address, breakpoint_kind),
+                "read packet: $Z{2},{0:x},{1}#00".format(
+                    address, breakpoint_kind, z_packet_type),
                 # Verify the stub could set it.
                 "send packet: $OK#00",
             ], True)
@@ -904,11 +905,15 @@ class GdbRemoteTestCaseBase(TestBase):
                                  2: "stop_thread_id"}},
                 ], True)
 
-    def add_remove_breakpoint_packets(self, address, breakpoint_kind=1):
+    def add_remove_breakpoint_packets(
+            self,
+            address,
+            z_packet_type=0,
+            breakpoint_kind=1):
         self.test_sequence.add_log_lines(
             [  # Remove the breakpoint.
-                "read packet: $z0,{0:x},{1}#00".format(
-                    address, breakpoint_kind),
+                "read packet: $z{2},{0:x},{1}#00".format(
+                    address, breakpoint_kind, z_packet_type),
                 # Verify the stub could unset it.
                 "send packet: $OK#00",
             ], True)
@@ -929,7 +934,8 @@ class GdbRemoteTestCaseBase(TestBase):
         "qXfer:libraries:read",
         "qXfer:libraries-svr4:read",
         "qXfer:features:read",
-        "qEcho"
+        "qEcho",
+        "QPassSignals"
     ]
 
     def parse_qSupported_response(self, context):
