@@ -5,7 +5,6 @@ Test that variables of floating point types are displayed correctly.
 from __future__ import print_function
 
 
-
 import AbstractBase
 import sys
 
@@ -14,6 +13,7 @@ from lldbsuite.test.decorators import *
 from lldbsuite.test.lldbtest import *
 from lldbsuite.test import lldbutil
 
+
 class FloatTypesTestCase(AbstractBase.GenericTester):
 
     mydir = AbstractBase.GenericTester.compute_mydir(__file__)
@@ -23,7 +23,8 @@ class FloatTypesTestCase(AbstractBase.GenericTester):
         AbstractBase.GenericTester.setUp(self)
         # disable "There is a running process, kill it and restart?" prompt
         self.runCmd("settings set auto-confirm true")
-        self.addTearDownHook(lambda: self.runCmd("settings clear auto-confirm"))
+        self.addTearDownHook(
+            lambda: self.runCmd("settings clear auto-confirm"))
 
     def test_float_type(self):
         """Test that float-type variables are displayed correctly."""
