@@ -17,7 +17,7 @@
 #include "CommandObjectHelp.h"
 #include "lldb/Core/Debugger.h"
 #include "lldb/Core/IOHandler.h"
-#include "lldb/Core/StringList.h"
+#include "lldb/Host/OptionParser.h"
 #include "lldb/Interpreter/Args.h"
 #include "lldb/Interpreter/CommandHistory.h"
 #include "lldb/Interpreter/CommandInterpreter.h"
@@ -28,6 +28,7 @@
 #include "lldb/Interpreter/OptionValueUInt64.h"
 #include "lldb/Interpreter/Options.h"
 #include "lldb/Interpreter/ScriptInterpreter.h"
+#include "lldb/Utility/StringList.h"
 
 using namespace lldb;
 using namespace lldb_private;
@@ -49,7 +50,11 @@ class CommandObjectCommandsHistory : public CommandObjectParsed {
 public:
   CommandObjectCommandsHistory(CommandInterpreter &interpreter)
       : CommandObjectParsed(interpreter, "command history",
-                            "Dump the history of commands in this session.",
+                            "Dump the history of commands in this session.\n"
+                            "Commands in the history list can be run again "
+                            "using \"!<INDEX>\".   \"!-<OFFSET>\" will re-run "
+                            "the command that is <OFFSET> commands from the end"
+                            " of the list (counting the current command).",
                             nullptr),
         m_options() {}
 
@@ -66,9 +71,9 @@ protected:
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
@@ -256,9 +261,9 @@ protected:
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
@@ -366,9 +371,9 @@ protected:
       return llvm::makeArrayRef(g_alias_options);
     }
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_value,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_value,
+                          ExecutionContext *execution_context) override {
+      Status error;
 
       const int short_option = GetDefinitions()[option_idx].short_option;
       std::string option_str(option_value);
@@ -574,7 +579,7 @@ protected:
         if (!ParseOptions(args, result))
           return false;
 
-        Error error(m_option_group.NotifyOptionParsingFinished(&exe_ctx));
+        Status error(m_option_group.NotifyOptionParsingFinished(&exe_ctx));
         if (error.Fail()) {
           result.AppendError(error.AsCString());
           result.SetStatus(eReturnStatusFailed);
@@ -1025,7 +1030,7 @@ protected:
         bool check_only = false;
         for (size_t i = 0; i < num_lines; ++i) {
           llvm::StringRef bytes_strref(lines[i]);
-          Error error = AppendRegexSubstitution(bytes_strref, check_only);
+          Status error = AppendRegexSubstitution(bytes_strref, check_only);
           if (error.Fail()) {
             if (!m_interpreter.GetDebugger()
                      .GetCommandInterpreter()
@@ -1053,7 +1058,7 @@ protected:
       return false;
     }
 
-    Error error;
+    Status error;
     auto name = command[0].ref;
     m_regex_cmd_ap = llvm::make_unique<CommandObjectRegexCommand>(
         m_interpreter, name, m_options.GetHelp(), m_options.GetSyntax(), 10, 0,
@@ -1096,9 +1101,9 @@ protected:
     return result.Succeeded();
   }
 
-  Error AppendRegexSubstitution(const llvm::StringRef &regex_sed,
-                                bool check_only) {
-    Error error;
+  Status AppendRegexSubstitution(const llvm::StringRef &regex_sed,
+                                 bool check_only) {
+    Status error;
 
     if (!m_regex_cmd_ap) {
       error.SetErrorStringWithFormat(
@@ -1210,9 +1215,9 @@ private:
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
@@ -1306,7 +1311,7 @@ protected:
                  CommandReturnObject &result) override {
     ScriptInterpreter *scripter = m_interpreter.GetScriptInterpreter();
 
-    Error error;
+    Status error;
 
     result.SetStatus(eReturnStatusInvalid);
 
@@ -1395,7 +1400,7 @@ protected:
                  CommandReturnObject &result) override {
     ScriptInterpreter *scripter = m_interpreter.GetScriptInterpreter();
 
-    Error error;
+    Status error;
 
     result.SetStatus(eReturnStatusInvalid);
 
@@ -1482,9 +1487,9 @@ protected:
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
@@ -1529,7 +1534,7 @@ protected:
     }
 
     for (auto &entry : command.entries()) {
-      Error error;
+      Status error;
 
       const bool init_session = true;
       // FIXME: this is necessary because CommandObject::CheckRequirements()
@@ -1614,9 +1619,9 @@ protected:
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
