@@ -15,6 +15,7 @@
 #include "llvm/ADT/StringRef.h"
 
 // Project includes
+#include "lldb/Host/OptionParser.h"
 #include "lldb/Interpreter/CommandCompletions.h"
 #include "lldb/Interpreter/CommandInterpreter.h"
 #include "lldb/Interpreter/CommandReturnObject.h"
@@ -101,9 +102,9 @@ insert-before or insert-after.");
 
     ~CommandOptions() override = default;
 
-    Error SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
-                         ExecutionContext *execution_context) override {
-      Error error;
+    Status SetOptionValue(uint32_t option_idx, llvm::StringRef option_arg,
+                          ExecutionContext *execution_context) override {
+      Status error;
       const int short_option = m_getopt_table[option_idx].val;
 
       switch (short_option) {
@@ -166,7 +167,7 @@ insert-before or insert-after.");
           // Complete setting value
           const char *setting_var_name =
               input.GetArgumentAtIndex(setting_var_idx);
-          Error error;
+          Status error;
           lldb::OptionValueSP value_sp(
               m_interpreter.GetDebugger().GetPropertyValue(
                   &m_exe_ctx, setting_var_name, false, error));
@@ -210,7 +211,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, false, false);
 
-    Error error;
+    Status error;
     if (m_options.m_global) {
       error = m_interpreter.GetDebugger().SetPropertyValue(
           nullptr, eVarSetOperationAssign, var_name, var_value_cstr);
@@ -295,7 +296,7 @@ protected:
 
     if (!args.empty()) {
       for (const auto &arg : args) {
-        Error error(m_interpreter.GetDebugger().DumpPropertyValue(
+        Status error(m_interpreter.GetDebugger().DumpPropertyValue(
             &m_exe_ctx, result.GetOutputStream(), arg.ref,
             OptionValue::eDumpGroupValue));
         if (error.Success()) {
@@ -493,7 +494,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, true, false);
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationRemove, var_name, var_value_cstr));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
@@ -601,7 +602,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, true, false);
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationReplace, var_name, var_value_cstr));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
@@ -715,7 +716,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, true, false);
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationInsertBefore, var_name, var_value_cstr));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
@@ -826,7 +827,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, true, false);
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationInsertAfter, var_name, var_value_cstr));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
@@ -928,7 +929,7 @@ protected:
     const char *var_value_cstr =
         Args::StripSpaces(var_value_string, true, true, false);
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationAppend, var_name, var_value_cstr));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
@@ -1005,7 +1006,7 @@ protected:
       return false;
     }
 
-    Error error(m_interpreter.GetDebugger().SetPropertyValue(
+    Status error(m_interpreter.GetDebugger().SetPropertyValue(
         &m_exe_ctx, eVarSetOperationClear, var_name, llvm::StringRef()));
     if (error.Fail()) {
       result.AppendError(error.AsCString());
