@@ -17,17 +17,17 @@
 using namespace lldb;
 using namespace lldb_private;
 
-lldb::MemoryHistorySP
-MemoryHistory::FindPlugin (const ProcessSP process)
-{
-    MemoryHistoryCreateInstance create_callback = nullptr;
-    
-    for (uint32_t idx = 0; (create_callback = PluginManager::GetMemoryHistoryCreateCallbackAtIndex(idx)) != nullptr; ++idx)
-    {
-        MemoryHistorySP memory_history_sp (create_callback (process));
-        if (memory_history_sp)
-            return memory_history_sp;
-    }
-    
-    return MemoryHistorySP();
+lldb::MemoryHistorySP MemoryHistory::FindPlugin(const ProcessSP process) {
+  MemoryHistoryCreateInstance create_callback = nullptr;
+
+  for (uint32_t idx = 0;
+       (create_callback = PluginManager::GetMemoryHistoryCreateCallbackAtIndex(
+            idx)) != nullptr;
+       ++idx) {
+    MemoryHistorySP memory_history_sp(create_callback(process));
+    if (memory_history_sp)
+      return memory_history_sp;
+  }
+
+  return MemoryHistorySP();
 }
